---
jupyter:
  jupytext:
    text_representation:
      extension: .md
      format_name: markdown
      format_version: '1.2'
      jupytext_version: 1.5.0.rc3
  kernelspec:
    display_name: Python 3
    language: python
    name: python3
---

```python

```
